import { AxiosInstance, AxiosRequestHeaders, AxiosRequestConfig } from 'axios';

declare class AjaxAxios {
    private static _defaultAxiosInstance;
    static setDefaultAxiosInstance(instance: AxiosInstance): void;
    private _axiosInstance;
    private _url;
    private _data;
    private _params;
    private _header;
    private _config;
    constructor(axiosInstance?: AxiosInstance);
    mountGet<T>(): Promise<T>;
    mountPost<T>(): Promise<T>;
    url(url: string): this;
    data(data: object): this;
    params(params: object): this;
    header(header: AxiosRequestHeaders): this;
    config(config: AxiosRequestConfig): this;
}
declare function createAxios(instance?: AxiosInstance): AjaxAxios;

declare class AjaxFetch {
    private _url;
    private _body;
    private _headers;
    private _config;
    private _controller;
    url(u: string): this;
    body(b: unknown, type?: 'json' | 'form' | 'unknown'): this;
    headers(h: object): this;
    header(k: string, v: unknown): this;
    config(c: object): this;
    config(k: string, v: unknown): this;
    execute(config: RequestInit): Promise<Response>;
    methodGet<T>(responseType?: 'text' | 'json' | 'formData' | 'blob' | 'arrayBuffer'): Promise<T>;
    methodPost<T>(responseType?: 'text' | 'json' | 'formData' | 'blob' | 'arrayBuffer'): Promise<T>;
    cancel(): void;
}
declare function createFetch(): AjaxFetch;

declare function createFormData(): {
    formData: FormData;
    factory: FormDataFactory;
};
type FormDataFactory = {
    append(...args: Parameters<FormData['append']>): FormDataFactory;
    delete(...args: Parameters<FormData['delete']>): FormDataFactory;
};

declare function createURLSearchParams(): {
    urlSearchParams: URLSearchParams;
    factory: URLSearchParamsFactory;
};
type URLSearchParamsFactory = {
    append(...args: Parameters<URLSearchParams['append']>): URLSearchParamsFactory;
    delete(...args: Parameters<URLSearchParams['delete']>): URLSearchParamsFactory;
};

export { AjaxAxios, AjaxFetch, type FormDataFactory, type URLSearchParamsFactory, createAxios, createFetch, createFormData, createURLSearchParams };
